ClaimerBuilder

Struct ClaimerBuilder 

pub struct ClaimerBuilder<I: Job, DE, DF, DFut>
where DF: Fn(I, usize) -> DFut + 'static + Send + Sync, DE: Display + Send + 'static, DFut: Future<Output = Result<(), DE>> + Send,
{ /* private fields */ }
Builder for constructing a Claimer.

Construct via ClaimerBuilder::new() and configure with chained setters:

let claimer = ClaimerBuilder::new()
    .min_idle_time(30_000)
    .max_retries(3)
    .dlq_worker(|payload: &Email, attempts| async move {
        Ok::<(), String>(())
    });

Implementations

Source

impl<I> ClaimerBuilder<I, NoDlqError, NoDlqFn<I>, NoDlqFut>
where I: Job,

pub fn new() -> Self

Construct a new ClaimerBuilder with sensible defaults.

Defaults: min_idle_time = 30_000, block_timeout = 10_000, max_concurrent_tasks = 1, max_retries = 3, no DLQ worker.

Source

impl<I, DE, DF, DFut> ClaimerBuilder<I, DE, DF, DFut>
where I: Job, DF: Fn(I, usize) -> DFut + 'static + Send + Sync, DE: Display + Send + 'static, DFut: Future<Output = Result<(), DE>> + Send,

pub fn min_idle_time(self, ms: usize) -> Self

Minimum idle time (ms) before a message is eligible for reclaiming.

pub fn block_timeout(self, ms: usize) -> Self

How long (ms) the claimer sleeps when there are no claimable messages.

pub fn max_concurrent_tasks(self, n: usize) -> Self

Maximum messages reclaimed concurrently.

pub fn max_retries(self, n: usize) -> Self

Delivery attempts before a message is sent to the DLQ.

pub fn dlq_worker<DE2, DF2, DFut2>( self, worker: DF2, ) -> ClaimerBuilder<I, DE2, DF2, DFut2>
where DF2: Fn(I, usize) -> DFut2 + 'static + Send + Sync, DE2: Display + Send + 'static, DFut2: Future<Output = Result<(), DE2>> + Send,

Attach a dead-letter callback.

Changes the builder’s generic parameters to match the worker’s signature.